File_tokenizer

Struct File_tokenizer 

pub struct File_tokenizer { /* private fields */ }
a Token Iterator on a given file

The structures Str_tokenizer and File_tokenizer both implement Iterator and return Tokens. File_tokenizer is more full-featured and recognizes multi-line string literals and multi-line comments, with the option of keeping the comments as special tokens. The File_tokenizer is also capable of distinguishing keywords (such as “if”, “else”, “while”) from other alphanumeric tokens.

Example:

  let mut fscan = File_tokenizer::new("test.c");
  fscan.add_keywords("while return");
  fscan.set_line_comment("//");
  fscan.set_keep_comments(false);
  fscan.set_keep_newline(true);
  while let Some(token) = fscan.next() {
    println!("{:?}, line {}",&token,fscan.line_number());
  }

Implementations

Source

impl File_tokenizer

pub fn new(filename: &str) -> File_tokenizer

creates a File_tokenizer given a file path, panics if file is not found

pub fn line_number(&self) -> usize

returns the current line number being read

pub fn column_number(&self) -> usize

returns the current column (character position) on the current line

pub fn current_line(&self) -> String

returns a copy of the current line being tokenized

pub fn add_keywords(&mut self, kws: &str)

adds keywords that are to be distinguished from other alphanumeric tokens. Keywords are returned as Keyword tokens. Keywords are specified using a whitespace-separated string.

Example:

let mut scanner = File_tokenizer::new("./somefilepath");
scanner.add_keywords("if else while for return break");
pub fn add_singletons(&mut self, singles: &str)

adds characters to be recognized as single-character Symbol tokens. For example, if ‘=’ is added as a singleton then “==” will be scanned as two separate Symbols. The default singletons are the brackets ( ) { } [ and ]. These characters are always recognized as singleton symbols.

Example

let mut scanner = File_tokenizer::new("./somefilepath");
scanner.add_singletons(".*");

Each character in the given string will be added to the default singletons. White-space and alphanumeric characters are ignored.

pub fn set_line_comment(&mut self, c: &str)

sets the symbol used to designate a single-line comment. The default symbol is “//”. The rest of the line is skipped after this symbol.

pub fn set_comments(&mut self, s: &str)

sets the symbols used to delineate possibly multiple-line comments. The default comment delimiters are “/*” and “*/”. The argument s should be a whitespace-separated string (e.g. “/* */”). The function has no effect if the argument is not of the right form.

pub fn no_line_comment(&mut self)

disables the recogniton of single-line comments. This option can only be re-enabled with Self::set_line_comment.

pub fn set_keep_comments(&mut self, b: bool)

sets option to keep comments delineated by set_comments as Verbatim tokens. Default is false (does not keep comments)

pub fn set_keep_newline(&mut self, b: bool)

sets option to emit the Newline token when a new line is read other than the first line. Newline is never emitted if inside a string literal or multi-line comment. The default is false.